.. gntplib documentation master file, created by
   sphinx-quickstart on Fri Mar  9 09:14:38 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to gntplib
==================

gntplib is a Growl Notification Transport Protocol (GNTP_) client library in
Python.

gntplib is tested on Python 2.7/3.2, Growl_ 1.3.3 and
`Growl for Windows`_ 2.0.9.

.. _GNTP: http://www.growlforwindows.com/gfw/help/gntp.aspx
.. _Growl: http://growl.info/
.. _Growl for Windows: http://www.growlforwindows.com/


.. toctree::
   :maxdepth: 3

   installation
   usage
   async
   api
